@@ -17,7 +17,7 @@
 
 require 'spec_helper'
 
-describe 'async_search.delete' do
+describe 'client#async_search.delete' do
   let(:expected_args) do
     [
       'DELETE',
@@ -25,7 +25,7 @@ describe 'async_search.delete' do
       {},
       nil,
       {},
-      { endpoint: 'count' }
+      { defined_params: { id: 'foo' }, endpoint: 'async_search.delete' }
     ]
   end
 
