@@ -63,9 +63,9 @@ if serverless?
   options.merge!(
     {
       retry_on_status: [409, 400, 503],
-      retry_on_failure: 20,
-      delay_on_retry: 10_000,
-      request_timeout: 120
+      retry_on_failure: 30,
+      delay_on_retry: 5_000,
+      request_timeout: 60
     }
   )
 end
@@ -81,7 +81,7 @@ logger.level = ENV['DEBUG'] ? Logger::DEBUG : Logger::WARN
 
 # If we're running in a release branch, download the corresponding branch for tests
 current_branch = `git rev-parse --abbrev-ref HEAD`.strip
-branch = ENV['ES_YAML_TESTS_BRANCH'] || current_branch.match(/[0-9]\.[0-9]+/)&.[](0) || nil
+branch = current_branch.match(/[0-9]\.[0-9]+/)&.[](0) || ENV['ES_YAML_TESTS_BRANCH'] || nil
 Elasticsearch::Tests::Downloader::run(tests_path, branch)
 
 runner = Elasticsearch::Tests::TestRunner.new(CLIENT, tests_path, logger)
